## Implement a new plot engine
If you want to add another plot engine "$engine" to plotID, this document helps you to do it. 

### tagplot
Create a new module named "tagplot_$engine.py". Paste the following code and replace every "$engine" with the name of your engine:  
```python
"""
Tag your picture with an ID.

Functions:
    tagplot_$engine(PlotOptions instance) -> list
"""
import $engine
from plotid.create_id import create_id
from plotid.plotoptions import PlotOptions


def tagplot_$engine(plotid_object):
    """
    Add IDs to plots with $engine.

    The ID is placed visual on the figure window and returned as string in a
    list together with the figures.
    TagPlot can tag multiple figures at once.
    """
    # Check if plotid_object is a valid instance of PlotOptions
    if not isinstance(plotid_object, PlotOptions):
        raise TypeError('The given options container is not an instance'
                        'of PlotOptions.')

    ids_as_list = []

    for fig in plotid_object.figs:
        figure_id = create_id(plotid_object.id_method)
        ids_as_list.append(figure_id)

        """
        Insert here the tagging with $engine:
        Open the figure fig.
        Place the string figure_id on it.
        Use plotid_object.position and plotid_object.rotation for position and rotation.
        Save the tagged figure to plotid_object.figs.
        """

    return [plotid_object.figs, ids_as_list]


Last step:
Add the following code in tagplot.py:
match engine:
    [...]
    case '$engine':
        return tagplot_$engine(option_container)
    case _:
        [...]
```

### publish
To include a new plot engine in the publish function only save_plot.py has to be touched.  
Import the plot engine at the top of the file.  
In the beginning of the function save_plot() create the following line:
```python
if isinstance(figures, $type_of_figure):
    figures = [figures]
[...]
if not isinstance(figures, list):
    raise TypeError('Figures are not given as list.')
```
This allows to iterate through all figures, even if it is only one. It must be placed before the line that checks if figures is a list.  

Create a new elif condition in the for loop:
```python
for i, fig in enumerate(figures):
    [...]
    elif isinstance(fig, $type_of_figure):
            # Read/Open the figure fig if necessary
            plot_path.append(plot_names[i] + '.' + extension)
            # Save the figure fig to plot_path[i]
```